==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/GetWorkloadDeploymentPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.GetWorkloadDeploymentPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property modernizeProjectName ModernizeProject name.
 * @property resourceGroupName Name of the Azure Resource Group that project is part of.
 * @property subscriptionId Azure Subscription Id in which project was created.
 * @property workloadDeploymentName Workload deployment name.
 */
public data class GetWorkloadDeploymentPlainArgs(
    public val modernizeProjectName: String,
    public val resourceGroupName: String,
    public val subscriptionId: String? = null,
    public val workloadDeploymentName: String,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.GetWorkloadDeploymentPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.migrate.inputs.GetWorkloadDeploymentPlainArgs =
        com.pulumi.azurenative.migrate.inputs.GetWorkloadDeploymentPlainArgs.builder()
            .modernizeProjectName(modernizeProjectName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .subscriptionId(subscriptionId?.let({ args0 -> args0 }))
            .workloadDeploymentName(workloadDeploymentName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetWorkloadDeploymentPlainArgs].
 */
@PulumiTagMarker
public class GetWorkloadDeploymentPlainArgsBuilder internal constructor() {
    private var modernizeProjectName: String? = null

    private var resourceGroupName: String? = null

    private var subscriptionId: String? = null

    private var workloadDeploymentName: String? = null

    /**
     * @param value ModernizeProject name.
     */
    @JvmName("fmuoduquradjyyiu")
    public suspend fun modernizeProjectName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.modernizeProjectName = mapped
    }

    /**
     * @param value Name of the Azure Resource Group that project is part of.
     */
    @JvmName("srthunvievbmoskt")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Azure Subscription Id in which project was created.
     */
    @JvmName("nqtpexvkghcnofmk")
    public suspend fun subscriptionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.subscriptionId = mapped
    }

    /**
     * @param value Workload deployment name.
     */
    @JvmName("lqrhntdlpqqognen")
    public suspend fun workloadDeploymentName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workloadDeploymentName = mapped
    }

    internal fun build(): GetWorkloadDeploymentPlainArgs = GetWorkloadDeploymentPlainArgs(
        modernizeProjectName = modernizeProjectName ?: throw
            PulumiNullFieldException("modernizeProjectName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        subscriptionId = subscriptionId,
        workloadDeploymentName = workloadDeploymentName ?: throw
            PulumiNullFieldException("workloadDeploymentName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/GetWorkloadDeploymentPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.GetWorkloadDeploymentPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property modernizeProjectName ModernizeProject name.
 * @property resourceGroupName Name of the Azure Resource Group that project is part of.
 * @property subscriptionId Azure Subscription Id in which project was created.
 * @property workloadDeploymentName Workload deployment name.
 */
public data class GetWorkloadDeploymentPlainArgs(
    public val modernizeProjectName: String,
    public val resourceGroupName: String,
    public val subscriptionId: String? = null,
    public val workloadDeploymentName: String,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.GetWorkloadDeploymentPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.migrate.inputs.GetWorkloadDeploymentPlainArgs =
        com.pulumi.azurenative.migrate.inputs.GetWorkloadDeploymentPlainArgs.builder()
            .modernizeProjectName(modernizeProjectName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .subscriptionId(subscriptionId?.let({ args0 -> args0 }))
            .workloadDeploymentName(workloadDeploymentName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetWorkloadDeploymentPlainArgs].
 */
@PulumiTagMarker
public class GetWorkloadDeploymentPlainArgsBuilder internal constructor() {
    private var modernizeProjectName: String? = null

    private var resourceGroupName: String? = null

    private var subscriptionId: String? = null

    private var workloadDeploymentName: String? = null

    /**
     * @param value ModernizeProject name.
     */
    @JvmName("gcdgylfdokkbtwel")
    public suspend fun modernizeProjectName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.modernizeProjectName = mapped
    }

    /**
     * @param value Name of the Azure Resource Group that project is part of.
     */
    @JvmName("nmeigkearftcaffk")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Azure Subscription Id in which project was created.
     */
    @JvmName("bnuqpgwqnniyjkua")
    public suspend fun subscriptionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.subscriptionId = mapped
    }

    /**
     * @param value Workload deployment name.
     */
    @JvmName("ssjiiyvcbcefrrgt")
    public suspend fun workloadDeploymentName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workloadDeploymentName = mapped
    }

    internal fun build(): GetWorkloadDeploymentPlainArgs = GetWorkloadDeploymentPlainArgs(
        modernizeProjectName = modernizeProjectName ?: throw
            PulumiNullFieldException("modernizeProjectName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        subscriptionId = subscriptionId,
        workloadDeploymentName = workloadDeploymentName ?: throw
            PulumiNullFieldException("workloadDeploymentName"),
    )
}
